(all-input source)(all-input source modified-dynamic-reader-fn)(classpath-matching path-part)(classpath-seq)(defn-special-binding fn-name default-specials args & body)(directory-seq dir)(directory-seq dir filter-re)(md5 x)(md5 x & rest)(nonempty-seq x)(read-all-input source)(read-dynamic-all-input source dynamic-reader-fn)(read-eval-with-sentinel reader)(reader! input)makes a reader one way or the other out of it's input. if it's a string that starts with @ then it's assumed a resource on CP.
makes a reader one way or the other out of it's input. if it's a string that starts with @ then it's assumed a resource on CP.
(resource-reader resource-name)(time-multiple-value expr)Evaluates expr and returns vector [result time].
Evaluates expr and returns vector [result time].
(uuid)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |